==> ae_droid-0.1.3.tar.gz: ae_droid-0.1.3/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# droid portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_droid/master?logo=python)](
    https://gitlab.com/ae-group/ae_droid)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_droid)](
    https://pypi.org/project/ae-droid/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_droid/coverage.svg)](
    https://ae-group.gitlab.io/ae_droid/coverage/ae_droid_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_droid/mypy.svg)](
    https://ae-group.gitlab.io/ae_droid/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_droid/pylint.svg)](
    https://ae-group.gitlab.io/ae_droid/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_droid)](
    https://libraries.io/pypi/ae-droid)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_droid)](
    https://pypi.org/project/ae-droid/#files)


## installation


Execute the following command for to use the ae.droid module in your
application. It will install ae.droid into your python (virtual) environment:
 
```shell script
pip install ae-droid
```

If you instead want to contribute to this portion then first fork
[the ae_droid repository at GitLab](https://gitlab.com/ae-group/ae_droid "ae.droid code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_droid):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.droid.html#module-ae.droid
"ae_droid documentation").

<!-- Common files version 0.1.66 deployed version 0.1.1 (with 0.1.66)
     to https://gitlab.com/ae-group as ae_droid module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-droid as namespace portion ae-droid.
-->

==> ae_droid-0.1.4.tar.gz: ae_droid-0.1.4/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# droid portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_droid/master?logo=python)](
    https://gitlab.com/ae-group/ae_droid)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_droid)](
    https://pypi.org/project/ae-droid/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_droid/coverage.svg)](
    https://ae-group.gitlab.io/ae_droid/coverage/ae_droid_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_droid/mypy.svg)](
    https://ae-group.gitlab.io/ae_droid/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_droid/pylint.svg)](
    https://ae-group.gitlab.io/ae_droid/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_droid)](
    https://pypi.org/project/ae-droid/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_droid)](
    https://libraries.io/pypi/ae-droid)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_droid)](
    https://pypi.org/project/ae-droid/#files)


## installation


Execute the following command to use the ae.droid module in your
application. It will install ae.droid into your python (virtual) environment:
 
```shell script
pip install ae-droid
```

If you instead want to contribute to this portion then first fork
[the ae_droid repository at GitLab](https://gitlab.com/ae-group/ae_droid "ae.droid code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_droid):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
To contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.droid.html#module-ae.droid
"ae_droid documentation").

<!-- Common files version 0.1.76 deployed version 0.2.3 (with 0.1.76)
     to https://gitlab.com/ae-group as ae_droid module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-droid as namespace portion ae-droid.
-->
